/*
USBIO Support Program
Copyright (C) 2001 by Masahiro Sekiguchi, all rights reserved.

Redistribution and use in source and/or binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote
   products derived from this software.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*/

package xyzzy.hardware;

/** SpiTarget is an abstract class to provide common code base for
    devices that operate as SPI targets.  This class is provided only
    to ease development of such classes; a Device is free not to
    extend SpiTarget.  Users of the classes, hence, must not assume an
    SPI client device is a subclass of SpiTarget.  */
abstract public class SpiTarget
    extends DeviceObject
{
    protected final SpiDevice spi;

    public SpiTarget ( final SpiDevice spi, final boolean lsbFirst )
    {
	super( spi.getLockObject() );
	spi.setLsbFirst( lsbFirst );
	this.spi = spi;
    }

    public void close ()
    {
	spi.close();
    }
}
