/*
USBIO Support Program
Copyright (C) 2001 by Masahiro Sekiguchi, all rights reserved.

Redistribution and use in source and/or binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote
   products derived from this software.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*/

package xyzzy.hardware.jdirect;

/** A class to provide some useful static methods to handle Windows
    GUID data.  Our GUID is represented with just a byte[] of length
    16.  */
final class GUID
{
    private static final char[] hex = "0123456789ABCDEF".toCharArray();

    private static void appendByte ( final StringBuffer buf, final byte x )
    {
	buf.append( hex[( x >> 4 ) & 15] )
	   .append( hex[  x        & 15] );
    }

    protected static String toString ( final byte[] guid )
    {
	final StringBuffer buf = new StringBuffer( 36 );
	for ( int i = 3; i >= 0; --i ) appendByte( buf, guid[i] );
	buf.append( '-' );
	for ( int i = 5; i >= 4; --i ) appendByte( buf, guid[i] );
	buf.append( '-' );
	for ( int i = 7; i >= 6; --i ) appendByte( buf, guid[i] );
	buf.append( '-' );
	for ( int i = 8; i <= 15; i++ ) appendByte( buf, guid[i] );
	return buf.toString();
    }
}
